@@ -10,7 +10,7 @@ def are_words_similar(s1: str, s2: str, threshold_jel: int = 2,threshold_seq: fl
         threshold_seq (float, optional): _description_. Defaults to 0.80.
 
     Returns:
-        bool: Match or not
+        bool: Match or not, rate
     """
     if min(len(s1),len(s1))<5:
         threshold_jel = 1
@@ -18,4 +18,5 @@ def are_words_similar(s1: str, s2: str, threshold_jel: int = 2,threshold_seq: fl
         threshold_seq = 0.85
     res1= jellyfish.damerau_levenshtein_distance(s1, s2) 
     res2 = SequenceMatcher(a=s1, b=s2).ratio() 
-    return res1<= threshold_jel or res2 >threshold_seq
\ No newline at end of file
+    res = res1<= threshold_jel or res2 >threshold_seq
+    return res,res2
\ No newline at end of file
