@@ -96,7 +96,7 @@ def selectElement(config,where,sql_select_query,one=False):
                 connection.close()
     return record
 
-def excecuteSQL(config,sql_query):
+def excecuteSQL(config,sql_query,return_id = -1):
     """ excecuteSQL brute for Create Table, Shama ... but not crud
 
     Args:
@@ -106,14 +106,20 @@ def excecuteSQL(config,sql_query):
     Returns:
         Boolean: resul of query (True or False)
     """
-    res = False
+    res = 0
+    if return_id==-1:
+        res = False
     connection = None
     try:
         connection = psycopg2.connect(host=config['host'],port=config['port'],database=config['database'],user=config['user'],password=config['password'])
         cursor = connection.cursor()
         cursor.execute(sql_query)
         connection.commit()
-        res = True
+        
+        if return_id==-1:
+            res = True
+        else:
+            res = cursor.fetchone()[return_id]
     except (Exception, psycopg2.Error) as error:
         print("Error while connecting to PostgreSQL :", error)
         writeLogTxt(name=getNameFileOutput()+'_Log.txt',data="Error excecuteSQL : "+str(error)+('**'*45)+'\n\n',root_directory_name="",dir_name = '_LOG_Postgres')
